@@ -1,7 +1,6 @@
-import unittest
 import copy
-from dataclasses import dataclass, field
-from typing import Any, Callable, Dict, List, NewType, Tuple, Optional
+from dataclasses import dataclass
+from typing import Any, Dict, List
 
 import pymich.middle_end.ir.instr_types as t
 from pymich.utils.helpers import Tree
@@ -53,26 +52,6 @@ class ParameterTree(Tree):
     def set_right(self, tree_node, value):
         tree_node.right_type = value
 
-    def left_side_tree_height(self, tree, height=0):
-        if type(tree) is not Or:
-            return height
-        else:
-            return self.left_side_tree_height(self.get_left(tree), height + 1)
-
-    def navigate_to_tree_leaf(self, tree, leaf_number, param):
-        if type(tree) is not Or:
-            return param
-
-        left_max_leaf_number = 2 ** self.left_side_tree_height(tree.left)
-        if leaf_number <= left_max_leaf_number:
-            return Left(self.navigate_to_tree_leaf(tree.left, leaf_number, param))
-        else:
-            return Right(
-                self.navigate_to_tree_leaf(
-                    tree.right, leaf_number - left_max_leaf_number, param
-                )
-            )
-
 
 class EntrypointTree(Tree):
     def make_node(self, left=None, right=None):
@@ -108,37 +87,26 @@ class Contract:
     def add_entrypoint(self, name: str, entrypoint: Entrypoint):
         self.entrypoints[name] = entrypoint
 
-    def make_contract_param(self, entrypoint_name, entrypoint_param):
-        entrypoint_names = sorted(self.entrypoints.keys())
-        if len(entrypoint_names) == 1:
-            return entrypoint_param
-
-        parameter_tree = ParameterTree()
-        tree = parameter_tree.list_to_tree(entrypoint_names)
-        entrypoint_index = entrypoint_names.index(entrypoint_name)
-        return parameter_tree.navigate_to_tree_leaf(
-            tree, entrypoint_index + 1, entrypoint_param
-        )
-
     def get_storage_type(self):
         return self.storage_type
 
     def get_parameter_type(self):
         entrypoint_names = self.entrypoints.keys()
         if len(entrypoint_names) == 1:
-            return self.entrypoints[entrypoint_names[0]].arg_type
+            entrypoint_name = list(entrypoint_names)[0]
+            return self.entrypoints[entrypoint_name].prototype.arg_type
         else:
             parameter_tree = ParameterTree()
             entrypoints = [
-                    self.entrypoints[name].prototype.arg_type
-                    for name in sorted(entrypoint_names)
-                ]
+                self.entrypoints[name].prototype.arg_type
+                for name in sorted(entrypoint_names)
+            ]
 
             for i, entrypoint in enumerate(entrypoints):
                 if type(entrypoint) == t.Record:
-                    # we do not want to override the record annotation for all record calls
-                    # but want to annotate them with the entrypoint name, so we copy it
-                    # and set the annotation then
+                    # we do not want to override the record annotation for all record
+                    # calls but want to annotate them with the entrypoint name, so we
+                    # copy it and set the annotation then
                     entrypoints[i] = copy.deepcopy(entrypoint)
                     entrypoints[i].annotation = "%" + sorted(list(entrypoint_names))[i]
                 else:
@@ -152,4 +120,3 @@ class Contract:
         ]
         entrypoint_tree = EntrypointTree()
         return entrypoint_tree.list_to_tree(entrypoints)
-
